pygeodesy.deprecated

Package pygeodesy :: Package deprecated |
[frames] | no frames]

# Package deprecated

DEPRECATED classes, constants, functions, interns, methods, etc. and all lazily imported.

Kept for backward compatibility, including DEPRECATED modules `pygeodesy.bases`, `pygeodesy.datum` and `pygeodesy.nvector`. Use either `from pygeodesy import bases` or `from pygeodesy.deprecated import bases`. Likewise for `datum` and `nvector`.

Version: 26.02.08

Submodules
pygeodesy.deprecated.bases: DEPRECATED on 2021.02.10, use (INTERNAL) module pygeodesy.latlonBase instead. pygeodesy.deprecated.classes: DEPRECATED classes kept for backward compatibility. pygeodesy.deprecated.consterns: DEPRECATED constants, interns and singletons kept for backward compatibility. pygeodesy.deprecated.datum: DEPRECATED on 2022.09.12, use module pygeodesy.datums or pygeodesy.ellipsoids instead. pygeodesy.deprecated.functions: DEPRECATED functions kept for backward compatibility. pygeodesy.deprecated.nvector: DEPRECATED on 2021.05.20, use (INTERNAL) module pygeodesy.nvectorBase instead. pygeodesy.deprecated.rhumbBase: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.bases instead. pygeodesy.deprecated.rhumbaux: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.aux_ instead. pygeodesy.deprecated.rhumbsolve: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.solve instead. pygeodesy.deprecated.rhumbx: DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.ekx instead.

Classes
| ClipCS3Tuple DEPRECATED, see DEPRECATED function pygeodesy.deprecated.clipCS3.
| Curvature2Tuple 2-Tuple `(meridional, prime_vertical)` of radii of curvature, both in `meter`, conventionally.
| Datum Ellipsoid and transform parameters for an earth model.
| EasNorExact4Tuple DEPRECATED, use class Forward4Tuple, item `gamma` for `convergence`.
| Elliperim DEPRECATED on 2026.02.06, use class Ellipse.
| Ellipsoid Ellipsoid with equatorial and polar radii, flattening, inverse flattening and other, often used, cached attributes, supporting oblate and prolate ellipsoidal and spherical earth models.
| Helmert7Tuple DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
| Jacobi2Tuple DEPRECATED on 25.11.11, use class Conformal2Tuple.
| JacobiConformal DEPRECATED on 2025.10.25, use class Conformal.
| JacobiConformalSpherical DEPRECATED on 2025.10.25, use class ConformalSphere.
| Lam_ DEPRECATED on 2024.06.15, use class Lamd.
| LatLonExact4Tuple DEPRECATED, use class Reverse4Tuple, item `gamma` for `convergence`.
| LatLonHeightBase DEPRECATED on 2021.02.10, use (INTERNAL) class pygeodesy.latlonBase.LatLonBase.
| LatLonNvectorBase (INTERNAL) Base class for n-vector-based ellipsoidal and spherical `LatLon`s.
| NearestOn4Tuple DEPRECATED on 2023.10.10, see methods RhumbLine.nearestOn4 and RhumbLineAux.nearestOn4.
| Ned3Tuple DEPRECATED, use class Ned4Tuple, ignoring item `ltp`.
| Nvector DEPRECATED on 2021.05.20, see (INTERNAL) class pygeodesy.nvectorBase.NvectorBase.
| Phi_ DEPRECATED on 2024.06.15, use class Phid.
| Rhumb7Tuple DEPRECATED, use class Rhumb8Tuple, ignoring item `a12`.
| RhumbOrder2Tuple DEPRECATED, see deprecated method Rhumb.orders.
| Transform Helmert datum transformation.
| Transform7Tuple DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
| TriAngle4Tuple DEPRECATED on 2023.09.14, use class TriAngle5Tuple, ignoring item `area`.
| UtmUps4Tuple DEPRECATED and OBSOLETE, expect a UtmUps5Tuple from method `pygeodesy.Mgrs.toUtm(utm=None)`.
| XDist DEPRECATED on 2024.07.02, use class ADict.

Functions
EcefCartesian(*args, **kwds) DEPRECATED, use class LocalCartesian. |
Fn_rt(root, *xs, **name_RESIDUAL_raiser) DEPRECATED on 2024.04.17, use class Froot. |
FrechetCosineAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class FrechetCosineLaw with `corr=1`. |
FrechetCosineForsytheAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class FrechetCosineLaw with `corr=2`. |
Fsum2product(*xs, **kwds) DEPRECATED on 2024.09.19, use Fsum`(*xs, f2product=True, ...)`. |
HausdorffCosineAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class HausdorffCosineLaw with `corr=1`. |
HausdorffCosineForsytheAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class HausdorffCosineLaw with `corr=2`. |
HeightIDW(knots, **kwds) DEPRECATED, use class HeightIDWeuclidean. |
HeightIDW2(knots, **kwds) DEPRECATED, use class HeightIDWequirectangular. |
HeightIDW3(knots, **kwds) DEPRECATED, use class HeightIDWhaversine. |
HeightIDWcosineAndoyerLambert(knots, **kwds) DEPRECATED on 2024.12.31, use class HeightIDWcosineLaw with `corr=1`. |
HeightIDWcosineForsytheAndoyerLambert(knots, **kwds) DEPRECATED on 2024.12.31, use class HeightIDWcosineLaw with `corr=2`. |
RefFrameError(*args, **kwds) DEPRECATED, use class TRFError. |
anStr(name, OKd=`'``._-``'`, sub='_') DEPRECATED, use function pygeodesy.anstr. |
areaof(points, adjust=True, radius=6371008.771415, wrap=True) DEPRECATED, use function pygeodesy.areaOf. |
atand(x) DEPRECATED on 2023.09.28, use function pygeodesy.atan1d. |
bounds(points, wrap=True, LatLon=None) DEPRECATED, use function pygeodesy.boundsOf. |
clipCS3(points, lowerleft, upperright, closed=False, inull=False) DEPRECATED, use function pygeodesy.clipCS4. |
clipDMS(deg, limit) DEPRECATED, use function pygeodesy.clipDegrees. |
clipStr(bstr, limit=50, white='') DEPRECATED, use function pygeodesy.clips. |
collins(pointA, pointB, pointC, alpha, beta, **useZ_Clas_and_kwds) DEPRECATED, use function pygeodesy.collins5. |
copysign(x, y) DEPRECATED, use function pygeodesy.copysign0. |
cosineAndoyerLambert(lat1, lon1, lat2, lon2, **datum_wrap) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=1`. |
cosineAndoyerLambert_(phi2, phi1, lam21, **datum) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=1`. |
cosineForsytheAndoyerLambert(lat1, lon1, lat2, lon2, **datum_wrap) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=2`. |
cosineForsytheAndoyerLambert_(phi2, phi1, lam21, **datum) DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=2`. |
decodeEPSG2(arg) DEPRECATED, use function epsg.decode2. |
elliperim(a, b, *deg2_1) DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc or property pygeodesy.Ellipse.perimeter2k_. |
elliperim_(a, b, *rad2_1) DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc_ or property pygeodesy.Ellipse.perimeter2k_. |
enStr2(easting, northing, prec, *extras) DEPRECATED, use function pygeodesy.enstr2. |
encodeEPSG(zone, hemipole='', band='') DEPRECATED, use function epsg.encode. |
equirectangular3(lat1, lon1, lat2, lon2, **options) DEPRECATED, use function pygeodesy.equirectangular4. |
equirectangular_(lat1, lon1, lat2, lon2, **options) DEPRECATED on 2024.05.25, use function pygeodesy.equirectangular4. |
excessAbc(A, b, c) DEPRECATED on 2023.04.04, use function pygeodesy.excessAbc_. |
excessGirard(A, B, C) DEPRECATED on 2023.04.04, use function pygeodesy.excessGirard_. |
excessLHuilier(a, b, c) DEPRECATED on 2023.04.04, use function pygeodesy.excessLHuilier_. |
fStr(floats, prec=6, fmt='f', ints=False, sep=', ') DEPRECATED, use function fstr. |
fStrzs(floatstr) DEPRECATED, use function pygeodesy.fstrzs. |
false2f(value, name=`'``value``'`, false=True, Error=<type 'exceptions.ValueError'>) DEPRECATED, use class Easting or Northing. |
falsed2f(falsed=True, Error=<type 'exceptions.ValueError'>, **name_value) DEPRECATED, use class Easting or Northing. |
float0(*xs) DEPRECATED on 2023.04.21, use function pygeodesy.float0_. |
hypot3(x, y, z) DEPRECATED, use function pygeodesy.hypot_. |
inStr(inst, *args, **kwds) DEPRECATED, use function pygeodesy.instr. |
isenclosedby(point, points, wrap=False) DEPRECATED, use function pygeodesy.isenclosedBy. |
istuplist(obj, minum=0) DEPRECATED on 2023.03.31, use function pygeodesy.islistuple. |
joined(*words, **sep) DEPRECATED, use `NN(...)`, `NN.join_` or `sep.join`. |
joined_(*words, **sep) DEPRECATED, use `_SPACE_(...)`, `_SPACE_.join_` or `sep.join`, sep=" ". |
nearestOn3(point, points, closed=False, wrap=False, **options) DEPRECATED, use function pygeodesy.nearestOn5. |
nearestOn4(point, points, closed=False, wrap=False, **options) DEPRECATED, use function pygeodesy.nearestOn5. |
parseUTM(strUTM, datum=_UTM, Utm=_UTM, name='') DEPRECATED, use function parseUTM5. |
perimeterof(points, closed=False, adjust=True, radius=6371008.771415, wrap=True) DEPRECATED, use function pygeodesy.perimeterOf. |
points2(points, closed=True, base=None, Error=<class 'pygeodesy.errors.PointsError'>) Check a path or polygon represented by points. |
polygon(points, closed=True, base=None) DEPRECATED, use function pygeodesy.points2. |
scalar(value, low=2.220446049250313e-16, high=1.0, name=`'``scalar``'`, Error=<type 'exceptions.ValueError'>) DEPRECATED, use class Number_ or Scalar_. |
simplify2(points, pipe=0.001, **radius_shortest_indices_options) DEPRECATED, use function pygeodesy.simplifyRW. |
simplifyRDPm(points, distance=0.001, **radius_shortest_indices_options) DEPRECATED on 2024.11.28, use function pygeodesy.simplifyRDP`(points, modified=True, ...)`. |
simplifyVWm(points, area=0.001, **radius_attr_indices_options) DEPRECATED on 2024.11.28, use function pygeodesy.simplifyVW`(points, modified=True, ...)`. |
sumOf(nvectors, Vector=None, h=None, **Vector_kwds) Return the vectorial sum of two or more n-vectors. |
tienstra(pointA, pointB, pointC, alpha, **beta_gamma_useZ_Clas_and_kwds) DEPRECATED, use function pygeodesy.tienstra7. |
toUtm(latlon, lon=None, datum=None, Utm=_UTM, cmoff=True, name='') DEPRECATED, use function pygeodesy.toUtm8. |
triAngle4(a, b, c) DEPRECATED on 2023.09.14, use function pygeodesy.triAngle5. |
unStr(name, *args, **kwds) DEPRECATED, use function pygeodesy.unstr. |
unsign0(x) DEPRECATED, use function pygeodesy.unsigned0. |
utmZoneBand2(lat, lon) DEPRECATED, use function pygeodesy.utmZoneBand5. |

Variables
| __getattr__ = `_lazy_import_as(__name__)`
| Datums = `Datums.Sphere: Datum(name='Sphere', ellipsoid=Ellipso`...``
| EPS1_2 = `0.9999999999999999`
| Ellipsoids = `Ellipsoids.Sphere: Ellipsoid(name='Sphere', a=637`...``
| MANTIS = `53`
| NorthPole = `_N_Vector(0, 0, 1)`
| OK = `'OK'`
| R_FM = `6371000.0`
| R_KM = `6371.0087714149995`
| R_M = `6371008.771415`
| R_MA = `6378137.0`
| R_MB = `6356752.3`
| R_NM = `3440.06953100162`
| R_SM = `3958.7613160486508`
| R_VM = `6366707.0194937`
| SouthPole = `_N_Vector(0, 0, -1)`
| Transforms = `Transforms.OSGB36: Transform(name='OSGB36', tx=-4`...``

Function Details

### Fsum2product (*xs, **kwds) |
DEPRECATED on 2024.09.19, use Fsum`(*xs, f2product=True, ...)`. Decorators: `@deprecated_function`

### anStr (name, OKd=`'``._-``'`, sub='_') |
DEPRECATED, use function pygeodesy.anstr. Decorators: `@deprecated_function`

### areaof (points, adjust=True, radius=6371008.771415, wrap=True) |
DEPRECATED, use function pygeodesy.areaOf. Decorators: `@deprecated_function`

### atand (x) |
DEPRECATED on 2023.09.28, use function pygeodesy.atan1d. Decorators: `@deprecated_function`

### bounds (points, wrap=True, LatLon=None) |
DEPRECATED, use function pygeodesy.boundsOf. Returns: 2-Tuple `(latlonSW, latlonNE)`, each a `LatLon` or 4-Tuple `(latS, lonW, latN, lonE)` if `LatLon is None`. Decorators: `@deprecated_function`

### clipCS3 (points, lowerleft, upperright, closed=False, inull=False) |
DEPRECATED, use function pygeodesy.clipCS4. Returns: Yield a ClipCS3Tuple`(start, end, index)` for each edge of the clipped path. Decorators: `@deprecated_function`

### clipDMS (deg, limit) |
DEPRECATED, use function pygeodesy.clipDegrees. Decorators: `@deprecated_function`

### clipStr (bstr, limit=50, white='') |
DEPRECATED, use function pygeodesy.clips. Decorators: `@deprecated_function`

### collins (pointA, pointB, pointC, alpha, beta, **useZ_Clas_and_kwds) |
DEPRECATED, use function pygeodesy.collins5. Decorators: `@deprecated_function`

### copysign (x, y) |
DEPRECATED, use function pygeodesy.copysign0. Decorators: `@deprecated_function`

### cosineAndoyerLambert (lat1, lon1, lat2, lon2, **datum_wrap) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=1`. Decorators: `@deprecated_function`

### cosineAndoyerLambert_ (phi2, phi1, lam21, **datum) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=1`. Decorators: `@deprecated_function`

### cosineForsytheAndoyerLambert (lat1, lon1, lat2, lon2, **datum_wrap) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw with `corr=2`. Decorators: `@deprecated_function`

### cosineForsytheAndoyerLambert_ (phi2, phi1, lam21, **datum) |
DEPRECATED on 2024.12.31, use function pygeodesy.cosineLaw_ with `corr=2`. Decorators: `@deprecated_function`

### decodeEPSG2 (arg) |
DEPRECATED, use function epsg.decode2. Returns: 2-Tuple `(zone, hemipole)` Decorators: `@deprecated_function`

### elliperim (a, b, *deg2_1) |
DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc or property pygeodesy.Ellipse.perimeter2k_. Decorators: `@deprecated_function`

### elliperim_ (a, b, *rad2_1) |
DEPRECATED on 2026.02.12, use method pygeodesy.Ellipse.arc_ or property pygeodesy.Ellipse.perimeter2k_. Decorators: `@deprecated_function`

### enStr2 (easting, northing, prec, *extras) |
DEPRECATED, use function pygeodesy.enstr2. Decorators: `@deprecated_function`

### encodeEPSG (zone, hemipole='', band='') |
DEPRECATED, use function epsg.encode. Returns: `EPSG` code (`int`). Decorators: `@deprecated_function`

### equirectangular3 (lat1, lon1, lat2, lon2, **options) |
DEPRECATED, use function pygeodesy.equirectangular4. Returns: 3-Tuple `(distance2, delta_lat, delta_lon)`. Decorators: `@deprecated_function`

### equirectangular_ (lat1, lon1, lat2, lon2, **options) |
DEPRECATED on 2024.05.25, use function pygeodesy.equirectangular4. Decorators: `@deprecated_function`

### excessAbc (A, b, c) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessAbc_. Decorators: `@deprecated_function`

### excessGirard (A, B, C) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessGirard_. Decorators: `@deprecated_function`

### excessLHuilier (a, b, c) |
DEPRECATED on 2023.04.04, use function pygeodesy.excessLHuilier_. Decorators: `@deprecated_function`

### fStr (floats, prec=6, fmt='f', ints=False, sep=', ') |
DEPRECATED, use function fstr. Decorators: `@deprecated_function`

### fStrzs (floatstr) |
DEPRECATED, use function pygeodesy.fstrzs. Decorators: `@deprecated_function`

### false2f (value, name=`'``value``'`, false=True, Error=<type 'exceptions.ValueError'>) |
DEPRECATED, use class Easting or Northing. Decorators: `@deprecated_function`

### falsed2f (falsed=True, Error=<type 'exceptions.ValueError'>, **name_value) |
DEPRECATED, use class Easting or Northing. Convert a falsed east-/northing to non-negative `float`. Arguments: `falsed` - Value includes false origin (`bool`). `Error` - Optional, overriding error (`Exception`). `name_value` - One `name=value` pair. Returns: The value (`float`). Decorators: `@deprecated_function` Raises: `Error` - Invalid or negative `name=value`.

### float0 (*xs) |
DEPRECATED on 2023.04.21, use function pygeodesy.float0_. Decorators: `@deprecated_function`

### hypot3 (x, y, z) |
DEPRECATED, use function pygeodesy.hypot_. Decorators: `@deprecated_function`

### inStr (inst, *args, **kwds) |
DEPRECATED, use function pygeodesy.instr. Decorators: `@deprecated_function`

### isenclosedby (point, points, wrap=False) |
DEPRECATED, use function pygeodesy.isenclosedBy. Decorators: `@deprecated_function`

### istuplist (obj, minum=0) |
DEPRECATED on 2023.03.31, use function pygeodesy.islistuple. Decorators: `@deprecated_function`

### joined (*words, **sep) |
DEPRECATED, use `NN(...)`, `NN.join_` or `sep.join`. Decorators: `@deprecated_function`

### joined_ (*words, **sep) |
DEPRECATED, use `_SPACE_(...)`, `_SPACE_.join_` or `sep.join`, sep=" ". Decorators: `@deprecated_function`

### nearestOn3 (point, points, closed=False, wrap=False, **options) |
DEPRECATED, use function pygeodesy.nearestOn5. Returns: 3-Tuple `(lat, lon, distance)` Decorators: `@deprecated_function`

### nearestOn4 (point, points, closed=False, wrap=False, **options) |
DEPRECATED, use function pygeodesy.nearestOn5. Returns: 4-Tuple `(lat, lon, distance, angle)` Decorators: `@deprecated_function`

### parseUTM (strUTM, datum=_UTM, Utm=_UTM, name='') |
DEPRECATED, use function parseUTM5. Returns: The UTM coordinate (Utm) or 4-tuple `(zone, hemisphere, easting, northing)` if `Utm is None`. Decorators: `@deprecated_function`

### perimeterof (points, closed=False, adjust=True, radius=6371008.771415, wrap=True) |
DEPRECATED, use function pygeodesy.perimeterOf. Decorators: `@deprecated_function`

### points2 (points, closed=True, base=None, Error=<class 'pygeodesy.errors.PointsError'>) |
Check a path or polygon represented by points. Arguments: `points` - The path or polygon points (`LatLon`[]) `closed` - Optionally, consider the polygon closed, ignoring any duplicate or closing final `points` (`bool`). `base` - Optionally, check all `points` against this base class, if `None` don't check. `Error` - Exception to raise (`ValueError`). Returns: A Points2Tuple`(number, points)` with the number of points and the points `list` or `tuple`. Raises: `PointsError` - Insufficient number of `points`. `TypeError` - Some `points` are not `base` compatible or composite `points`.

### polygon (points, closed=True, base=None) |
DEPRECATED, use function pygeodesy.points2. Decorators: `@deprecated_function`

### scalar (value, low=2.220446049250313e-16, high=1.0, name=`'``scalar``'`, Error=<type 'exceptions.ValueError'>) |
DEPRECATED, use class Number_ or Scalar_. Returns: New value (`float` or `int` for `int` `low`). Decorators: `@deprecated_function` Raises: `Error` - Invalid `value`.

### simplify2 (points, pipe=0.001, **radius_shortest_indices_options) |
DEPRECATED, use function pygeodesy.simplifyRW. Decorators: `@deprecated_function`

### simplifyRDPm (points, distance=0.001, **radius_shortest_indices_options) |
DEPRECATED on 2024.11.28, use function pygeodesy.simplifyRDP`(points, modified=True, ...)`. Decorators: `@deprecated_function`

### simplifyVWm (points, area=0.001, **radius_attr_indices_options) |
DEPRECATED on 2024.11.28, use function pygeodesy.simplifyVW`(points, modified=True, ...)`. Decorators: `@deprecated_function`

### sumOf (nvectors, Vector=None, h=None, **Vector_kwds) |
Return the vectorial sum of two or more n-vectors. Arguments: `nvectors` - Vectors to be added (`Nvector`[]). `Vector` - Optional class for the vectorial sum (`Nvector`) or `None`. `h` - Optional height, overriding the mean height (`meter`). `Vector_kwds` - Optional, additional `Vector` keyword arguments, ignored if `Vector is None`. Returns: Vectorial sum (`Vector`) or a Vector4Tuple`(x, y, z, h)` if `Vector is None`. Raises: `VectorError` - No `nvectors`.

### tienstra (pointA, pointB, pointC, alpha, **beta_gamma_useZ_Clas_and_kwds) |
DEPRECATED, use function pygeodesy.tienstra7. Decorators: `@deprecated_function`

### toUtm (latlon, lon=None, datum=None, Utm=_UTM, cmoff=True, name='') |
DEPRECATED, use function pygeodesy.toUtm8. Returns: The UTM coordinate (`Utm`) or a 6-tuple `(zone, easting, northing, band, convergence, scale)` if `Utm is None` or `cmoff is False`. Decorators: `@deprecated_function`

### triAngle4 (a, b, c) |
DEPRECATED on 2023.09.14, use function pygeodesy.triAngle5. Returns: A DEPRECATED TriAngle4Tuple`(radA, radB, radC, rIn)`. Decorators: `@deprecated_function`

### unStr (name, *args, **kwds) |
DEPRECATED, use function pygeodesy.unstr. Decorators: `@deprecated_function`

### unsign0 (x) |
DEPRECATED, use function pygeodesy.unsigned0. Decorators: `@deprecated_function`

### utmZoneBand2 (lat, lon) |
DEPRECATED, use function pygeodesy.utmZoneBand5. Returns: 2-Tuple `(zone, band)`. Decorators: `@deprecated_function`

Variables Details

  ### Datums Value:
      Datums.Sphere: Datum(name='Sphere', ellipsoid=Ellipsoids.Sphere, trans
      form=Transforms.WGS84),
      Datums.NAD83: Datum(name='NAD83', ellipsoid=Ellipsoids.GRS80, transfor
      m=Transforms.NAD83),
      Datums.OSGB36: Datum(name='OSGB36', ellipsoid=Ellipsoids.Airy1830, tra
      nsform=Transforms.OSGB36),
      Datums.WGS84: Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transfor
      m=Transforms.WGS84),
      ...

  ### Ellipsoids Value:
      Ellipsoids.Sphere: Ellipsoid(name='Sphere', a=6371008.771415, f=0, f_=
      0, b=6371008.771415),
      Ellipsoids.GRS80: Ellipsoid(name='GRS80', a=6378137, f=0.00335281, f_=
      298.2572221, b=6356752.31414035),
      Ellipsoids.WGS84: Ellipsoid(name='WGS84', a=6378137, f=0.00335281, f_=
      298.25722356, b=6356752.31424518),
      Ellipsoids.Airy1830: Ellipsoid(name='Airy1830', a=6377563.396, f=0.003
      34085, f_=299.3249646, b=6356256.90923729)

  ### Transforms Value:
      Transforms.OSGB36: Transform(name='OSGB36', tx=-446.45, ty=125.16, tz=
      -542.06, s1=1.0, rx=-7.2819e-07, ry=-1.1975e-06, rz=-4.0826e-06, s=20.
      489, sx=-0.1502, sy=-0.247, sz=-0.8421),
      Transforms.NAD83: Transform(name='NAD83', tx=1.004, ty=-1.91, tz=-0.51
      5, s1=1.0, rx=1.2945e-07, ry=1.6484e-09, rz=5.333e-08, s=-0.0015, sx=0
      .0267, sy=0.00034, sz=0.011),
      Transforms.WGS84: Transform(name='WGS84', tx=0.0, ty=0.0, tz=0.0, s1=1
      .0, rx=0.0, ry=0.0, rz=0.0, s=0.0, sx=0.0, sy=0.0, sz=0.0),
      ...